@@ -41,7 +41,7 @@ impl Parser{
         let input = getchar();
         match input{
             Ok(v) => Ok( self.tape.set_current_value( Wrapping(v) )),
-            Err(_) => Err( String::from("Runtime error: Used up given input but more is needed, Exiting!") ),
+            Err(e) => Err( format!("Runtime error: {}", e) ),
         }
     }
 
@@ -100,7 +100,7 @@ impl Parser{
 
     pub fn execute(&mut self, program: &str, numerical_mode: bool, debug_mode: bool) -> Result<(), String>{
         while self.program_counter < program.len(){
-            let error: Result<(), String> = match program.chars().nth(self.program_counter).unwrap(){
+            let error: Result<(), String> = match program.chars().nth(self.program_counter).unwrap_or(' '){
                 '-' => Ok( self.tape.dec() ),
                 '+' => Ok( self.tape.inc() ),
                 '<' => self.tape.move_left(),
