@@ -2,7 +2,7 @@ use std::io;
 use std::io::{Read, Write};
 use termion::raw::IntoRawMode;
 
-pub fn getchar() -> Result<u8, ()>{
+pub fn getchar() -> Result<u8, String>{
     let mut buffer = [0];
     let stdout = io::stdout().into_raw_mode().unwrap();
     let mut stdin = io::stdin();
@@ -11,10 +11,15 @@ pub fn getchar() -> Result<u8, ()>{
 
     // TODO: this looks like it could be done more concisely
     return if let Ok(_) = stdin.read_exact(&mut buffer){
-        Ok( buffer[0] )
+        if buffer[0] == 3{
+            Err( String::from("got Ctrl-C, Exiting!") )
+        }
+        else{
+            Ok( buffer[0] )
+        }
     }
     else{
-        Err( () )
+        Err( String::from("not enough input given") )
     }
 }
 
